# root.generated.openapi-client
Root Signals JSON API provides a way to access Root Signals using provisioned API token

The `root.generated.openapi_client` package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0 (latest)
- Package version: 1.0.0
- Generator version: 7.4.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage

This python library package is generated without supporting files like setup.py or requirements files

To be able to use it, you will need these dependencies in your own package that uses this library:

* urllib3 >= 1.25.3
* python-dateutil
* pydantic

## Getting Started

In your own code, to use this library to connect and interact with root.generated.openapi-client,
you can run the following:

```python

import root.generated.openapi_client
from root.generated.openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.app.rootsignals.ai
# See configuration.py for a list of all supported configuration parameters.
configuration = root.generated.openapi_client.Configuration(
    host = "https://api.app.rootsignals.ai"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure API key authorization: publicApiKey
configuration.api_key['publicApiKey'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['publicApiKey'] = 'Bearer'


# Enter a context with an instance of the API client
with root.generated.openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = root.generated.openapi_client.ChatsApi(api_client)
    chat_id = 'chat_id_example' # str | 
    chat_execution_request_request = {"variables":{"job_title":"software developer","question":"please write some basic python code"}} # ChatExecutionRequestRequest |  (optional)

    try:
        api_response = api_instance.chats_execute_create(chat_id, chat_execution_request_request=chat_execution_request_request)
        print("The response of ChatsApi->chats_execute_create:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ChatsApi->chats_execute_create: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.app.rootsignals.ai*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ChatsApi* | [**chats_execute_create**](root/generated/openapi_client/docs/ChatsApi.md#chats_execute_create) | **POST** /v1/chats/{chat_id}/execute/ | 
*ChatsApi* | [**chats_initiate_create**](root/generated/openapi_client/docs/ChatsApi.md#chats_initiate_create) | **POST** /v1/chats/initiate/ | 
*ChatsApi* | [**chats_initiate_create2**](root/generated/openapi_client/docs/ChatsApi.md#chats_initiate_create2) | **POST** /v1/chats/{chat_id}/initiate/ | 
*ChatsApi* | [**chats_list**](root/generated/openapi_client/docs/ChatsApi.md#chats_list) | **GET** /v1/chats/ | 
*ChatsApi* | [**chats_messages_status_retrieve**](root/generated/openapi_client/docs/ChatsApi.md#chats_messages_status_retrieve) | **GET** /v1/chats/{chat_id}/messages/{correlation_id}/status/ | 
*ChatsApi* | [**chats_retrieve**](root/generated/openapi_client/docs/ChatsApi.md#chats_retrieve) | **GET** /v1/chats/{chat_id}/ | 
*DatasetsApi* | [**datasets_create**](root/generated/openapi_client/docs/DatasetsApi.md#datasets_create) | **POST** /v1/datasets/ | 
*DatasetsApi* | [**datasets_destroy**](root/generated/openapi_client/docs/DatasetsApi.md#datasets_destroy) | **DELETE** /v1/datasets/{id}/ | 
*DatasetsApi* | [**datasets_list**](root/generated/openapi_client/docs/DatasetsApi.md#datasets_list) | **GET** /v1/datasets/ | 
*DatasetsApi* | [**datasets_retrieve**](root/generated/openapi_client/docs/DatasetsApi.md#datasets_retrieve) | **GET** /v1/datasets/{id}/ | 
*ExecutionLogsApi* | [**execution_logs_list**](root/generated/openapi_client/docs/ExecutionLogsApi.md#execution_logs_list) | **GET** /v1/execution-logs/ | 
*ExecutionLogsApi* | [**execution_logs_retrieve**](root/generated/openapi_client/docs/ExecutionLogsApi.md#execution_logs_retrieve) | **GET** /v1/execution-logs/{log_id}/ | 
*ModelsApi* | [**models_create**](root/generated/openapi_client/docs/ModelsApi.md#models_create) | **POST** /v1/models/ | 
*ModelsApi* | [**models_destroy**](root/generated/openapi_client/docs/ModelsApi.md#models_destroy) | **DELETE** /v1/models/{id}/ | 
*ModelsApi* | [**models_list**](root/generated/openapi_client/docs/ModelsApi.md#models_list) | **GET** /v1/models/ | 
*ModelsApi* | [**models_retrieve**](root/generated/openapi_client/docs/ModelsApi.md#models_retrieve) | **GET** /v1/models/{id}/ | 
*ObjectivesApi* | [**objectives_create**](root/generated/openapi_client/docs/ObjectivesApi.md#objectives_create) | **POST** /v1/objectives/ | 
*ObjectivesApi* | [**objectives_destroy**](root/generated/openapi_client/docs/ObjectivesApi.md#objectives_destroy) | **DELETE** /v1/objectives/{id}/ | 
*ObjectivesApi* | [**objectives_list**](root/generated/openapi_client/docs/ObjectivesApi.md#objectives_list) | **GET** /v1/objectives/ | 
*ObjectivesApi* | [**objectives_partial_update**](root/generated/openapi_client/docs/ObjectivesApi.md#objectives_partial_update) | **PATCH** /v1/objectives/{id}/ | 
*ObjectivesApi* | [**objectives_retrieve**](root/generated/openapi_client/docs/ObjectivesApi.md#objectives_retrieve) | **GET** /v1/objectives/{id}/ | 
*ObjectivesApi* | [**objectives_update**](root/generated/openapi_client/docs/ObjectivesApi.md#objectives_update) | **PUT** /v1/objectives/{id}/ | 
*SkillsApi* | [**get_a_list_of_all_versions_of_a_skill**](root/generated/openapi_client/docs/SkillsApi.md#get_a_list_of_all_versions_of_a_skill) | **GET** /v1/skills/versions/{id}/ | 
*SkillsApi* | [**skills_calibrate_create**](root/generated/openapi_client/docs/SkillsApi.md#skills_calibrate_create) | **POST** /v1/skills/calibrate/ | 
*SkillsApi* | [**skills_calibrate_create2**](root/generated/openapi_client/docs/SkillsApi.md#skills_calibrate_create2) | **POST** /v1/skills/calibrate/{id} | 
*SkillsApi* | [**skills_create**](root/generated/openapi_client/docs/SkillsApi.md#skills_create) | **POST** /v1/skills/ | 
*SkillsApi* | [**skills_destroy**](root/generated/openapi_client/docs/SkillsApi.md#skills_destroy) | **DELETE** /v1/skills/{id}/ | 
*SkillsApi* | [**skills_duplicate_create**](root/generated/openapi_client/docs/SkillsApi.md#skills_duplicate_create) | **POST** /v1/skills/duplicate/{id}/ | 
*SkillsApi* | [**skills_evaluator_execute_create**](root/generated/openapi_client/docs/SkillsApi.md#skills_evaluator_execute_create) | **POST** /v1/skills/evaluator/execute/{skill_id}/ | 
*SkillsApi* | [**skills_execute_create**](root/generated/openapi_client/docs/SkillsApi.md#skills_execute_create) | **POST** /v1/skills/execute/{id}/ | 
*SkillsApi* | [**skills_execute_validators_create**](root/generated/openapi_client/docs/SkillsApi.md#skills_execute_validators_create) | **POST** /v1/skills/execute-validators/{id}/ | 
*SkillsApi* | [**skills_list**](root/generated/openapi_client/docs/SkillsApi.md#skills_list) | **GET** /v1/skills/ | 
*SkillsApi* | [**skills_openai_chat_completions_create**](root/generated/openapi_client/docs/SkillsApi.md#skills_openai_chat_completions_create) | **POST** /v1/skills/openai/{skill_id}/chat/completions | 
*SkillsApi* | [**skills_partial_update**](root/generated/openapi_client/docs/SkillsApi.md#skills_partial_update) | **PATCH** /v1/skills/{id}/ | 
*SkillsApi* | [**skills_retrieve**](root/generated/openapi_client/docs/SkillsApi.md#skills_retrieve) | **GET** /v1/skills/{id}/ | 
*SkillsApi* | [**skills_status_create**](root/generated/openapi_client/docs/SkillsApi.md#skills_status_create) | **POST** /v1/skills/status/{id}/ | 
*SkillsApi* | [**skills_test_create**](root/generated/openapi_client/docs/SkillsApi.md#skills_test_create) | **POST** /v1/skills/test/ | 
*SkillsApi* | [**skills_test_create2**](root/generated/openapi_client/docs/SkillsApi.md#skills_test_create2) | **POST** /v1/skills/test/{id} | 
*SkillsApi* | [**skills_update**](root/generated/openapi_client/docs/SkillsApi.md#skills_update) | **PUT** /v1/skills/{id}/ | 


## Documentation For Models

 - [Chat](root/generated/openapi_client/docs/Chat.md)
 - [ChatCreateRequest](root/generated/openapi_client/docs/ChatCreateRequest.md)
 - [ChatDetail](root/generated/openapi_client/docs/ChatDetail.md)
 - [ChatExecutionRequestRequest](root/generated/openapi_client/docs/ChatExecutionRequestRequest.md)
 - [ChatExecutionResult](root/generated/openapi_client/docs/ChatExecutionResult.md)
 - [ChatMessage](root/generated/openapi_client/docs/ChatMessage.md)
 - [DataLoader](root/generated/openapi_client/docs/DataLoader.md)
 - [DataLoaderRequest](root/generated/openapi_client/docs/DataLoaderRequest.md)
 - [DataLoaderTypeEnum](root/generated/openapi_client/docs/DataLoaderTypeEnum.md)
 - [DataSetCreate](root/generated/openapi_client/docs/DataSetCreate.md)
 - [DataSetCreateRequest](root/generated/openapi_client/docs/DataSetCreateRequest.md)
 - [DataSetList](root/generated/openapi_client/docs/DataSetList.md)
 - [DataSetType](root/generated/openapi_client/docs/DataSetType.md)
 - [EvaluatorDemonstrations](root/generated/openapi_client/docs/EvaluatorDemonstrations.md)
 - [EvaluatorDemonstrationsRequest](root/generated/openapi_client/docs/EvaluatorDemonstrationsRequest.md)
 - [EvaluatorExecutionFunctionParameterPropertyRequest](root/generated/openapi_client/docs/EvaluatorExecutionFunctionParameterPropertyRequest.md)
 - [EvaluatorExecutionFunctionParameterRequest](root/generated/openapi_client/docs/EvaluatorExecutionFunctionParameterRequest.md)
 - [EvaluatorExecutionFunctionParameterTypeEnum](root/generated/openapi_client/docs/EvaluatorExecutionFunctionParameterTypeEnum.md)
 - [EvaluatorExecutionFunctionRequest](root/generated/openapi_client/docs/EvaluatorExecutionFunctionRequest.md)
 - [EvaluatorExecutionFunctionsRequest](root/generated/openapi_client/docs/EvaluatorExecutionFunctionsRequest.md)
 - [EvaluatorExecutionFunctionsTypeEnum](root/generated/openapi_client/docs/EvaluatorExecutionFunctionsTypeEnum.md)
 - [EvaluatorExecutionRequest](root/generated/openapi_client/docs/EvaluatorExecutionRequest.md)
 - [EvaluatorExecutionResult](root/generated/openapi_client/docs/EvaluatorExecutionResult.md)
 - [ID](root/generated/openapi_client/docs/ID.md)
 - [InputVariable](root/generated/openapi_client/docs/InputVariable.md)
 - [InputVariableRequest](root/generated/openapi_client/docs/InputVariableRequest.md)
 - [Model](root/generated/openapi_client/docs/Model.md)
 - [ModelCreate](root/generated/openapi_client/docs/ModelCreate.md)
 - [ModelCreateRequest](root/generated/openapi_client/docs/ModelCreateRequest.md)
 - [ModelParams](root/generated/openapi_client/docs/ModelParams.md)
 - [ModelParamsRequest](root/generated/openapi_client/docs/ModelParamsRequest.md)
 - [NestedObjectiveList](root/generated/openapi_client/docs/NestedObjectiveList.md)
 - [NestedSkillEvaluator](root/generated/openapi_client/docs/NestedSkillEvaluator.md)
 - [NestedSkillEvaluatorRequest](root/generated/openapi_client/docs/NestedSkillEvaluatorRequest.md)
 - [NestedUserDetails](root/generated/openapi_client/docs/NestedUserDetails.md)
 - [Objective](root/generated/openapi_client/docs/Objective.md)
 - [ObjectiveList](root/generated/openapi_client/docs/ObjectiveList.md)
 - [ObjectiveRequest](root/generated/openapi_client/docs/ObjectiveRequest.md)
 - [OpenAIChatCompletionRequest](root/generated/openapi_client/docs/OpenAIChatCompletionRequest.md)
 - [OpenAIMessageRequest](root/generated/openapi_client/docs/OpenAIMessageRequest.md)
 - [PaginatedChatList](root/generated/openapi_client/docs/PaginatedChatList.md)
 - [PaginatedDataSetListList](root/generated/openapi_client/docs/PaginatedDataSetListList.md)
 - [PaginatedModelList](root/generated/openapi_client/docs/PaginatedModelList.md)
 - [PaginatedObjectiveListList](root/generated/openapi_client/docs/PaginatedObjectiveListList.md)
 - [PaginatedSkillExecutionLogListList](root/generated/openapi_client/docs/PaginatedSkillExecutionLogListList.md)
 - [PaginatedSkillList](root/generated/openapi_client/docs/PaginatedSkillList.md)
 - [PaginatedSkillListOutputList](root/generated/openapi_client/docs/PaginatedSkillListOutputList.md)
 - [PatchedObjectiveRequest](root/generated/openapi_client/docs/PatchedObjectiveRequest.md)
 - [PatchedSkillRequest](root/generated/openapi_client/docs/PatchedSkillRequest.md)
 - [Provider](root/generated/openapi_client/docs/Provider.md)
 - [ReferenceVariable](root/generated/openapi_client/docs/ReferenceVariable.md)
 - [ReferenceVariableDynamicDatasetsRequest](root/generated/openapi_client/docs/ReferenceVariableDynamicDatasetsRequest.md)
 - [ReferenceVariableRequest](root/generated/openapi_client/docs/ReferenceVariableRequest.md)
 - [RoleEnum](root/generated/openapi_client/docs/RoleEnum.md)
 - [Skill](root/generated/openapi_client/docs/Skill.md)
 - [SkillExecutionLogDetails](root/generated/openapi_client/docs/SkillExecutionLogDetails.md)
 - [SkillExecutionLogDetailsSkill](root/generated/openapi_client/docs/SkillExecutionLogDetailsSkill.md)
 - [SkillExecutionLogList](root/generated/openapi_client/docs/SkillExecutionLogList.md)
 - [SkillExecutionRequest](root/generated/openapi_client/docs/SkillExecutionRequest.md)
 - [SkillExecutionResult](root/generated/openapi_client/docs/SkillExecutionResult.md)
 - [SkillExecutionValidatorResult](root/generated/openapi_client/docs/SkillExecutionValidatorResult.md)
 - [SkillListOutput](root/generated/openapi_client/docs/SkillListOutput.md)
 - [SkillRequest](root/generated/openapi_client/docs/SkillRequest.md)
 - [SkillStatus](root/generated/openapi_client/docs/SkillStatus.md)
 - [SkillStatusRequest](root/generated/openapi_client/docs/SkillStatusRequest.md)
 - [SkillTestDataRequest](root/generated/openapi_client/docs/SkillTestDataRequest.md)
 - [SkillTestInputRequest](root/generated/openapi_client/docs/SkillTestInputRequest.md)
 - [SkillTestOutput](root/generated/openapi_client/docs/SkillTestOutput.md)
 - [SkillTypeEnum](root/generated/openapi_client/docs/SkillTypeEnum.md)
 - [SkillValidator](root/generated/openapi_client/docs/SkillValidator.md)
 - [SkillValidatorExecutionRequest](root/generated/openapi_client/docs/SkillValidatorExecutionRequest.md)
 - [SkillValidatorExecutionResult](root/generated/openapi_client/docs/SkillValidatorExecutionResult.md)
 - [SkillValidatorRequest](root/generated/openapi_client/docs/SkillValidatorRequest.md)
 - [StatusEnum](root/generated/openapi_client/docs/StatusEnum.md)
 - [Validation](root/generated/openapi_client/docs/Validation.md)
 - [ValidationResultStatus](root/generated/openapi_client/docs/ValidationResultStatus.md)
 - [ValidatorResult](root/generated/openapi_client/docs/ValidatorResult.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="publicApiKey"></a>
### publicApiKey

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header

<a id="tokenAuth"></a>
### tokenAuth

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author




